@@ -32,13 +32,13 @@ class TrackerCallback(Callback):
         return message
 
     def save_model(self) -> None:
-        local_prefix = os.path.join(io.get_temporary_local_directory_path(), 'weights')
+        local_prefix = os.path.join(io.generate_path(prefix=None), 'weights')
 
         self.model.save_weights(local_prefix)
         self.tracker.save_model(local_prefix)
 
     def save_config(self) -> None:
-        local_file = os.path.join(io.get_temporary_local_directory_path(), 'config.json')
+        local_file = os.path.join(io.generate_path(prefix=None), 'config.json')
 
         with io.open(local_file, mode='w') as json_file:
             json.dump(self.model.get_config(), json_file)
